#include <Wire.h>
#include <Adafruit_BMP085.h>

// Beispielanwendung zum Auslesen des BMP085 Sensors zur Messung des Luftdruckes.
// Dieser Sensor benutzt I2C zur Komunikation, somit werden nur 2 Pins benötigt.

/***************************************************
  This is an example for the BMP085 Barometric Pressure & Temp Sensor

  Designed specifically to work with the Adafruit BMP085 Breakout
  ----> https://www.adafruit.com/products/391

  These displays use I2C to communicate, 2 pins are required to
  interface
  Adafruit invests time and resources providing this open source code,
  please support Adafruit and open-source hardware by purchasing
  products from Adafruit!

  Written by Limor Fried/Ladyada for Adafruit Industries.
  BSD license, all text above must be included in any redistribution
 ****************************************************/

// Anschlüsse
// 3.3V (NICHT 5.0V!) mit den beiden Vdd Anschlüssen des BMP085 Sensor verbinden
// GND mit Masse verbinden
// SCL mit dem I2C Clock verbinden (beim Arduino Uno extra Anschluss, ansonsten Analog 5)
// SDA mit dem I2C DATA verbinden (beim Arduino Uno extra Anschluss, ansonsten Analog 4)
// EOC wird nicht benutzt, signalisiert das Ende einer Konvertierung.
// XCLR ist der Reset Pin, wird ebenfalls hier nicht benutzt.

Adafruit_BMP085 bmp;

void setup() {
  Serial.begin(115000);
  while (!Serial) {
  }
  Serial.println(F("Init I2C"));
  // Initialisierung des Sensors
  if (!bmp.begin()) {
    // Kein Sensor gefunden
    Serial.println("Keinen BMP085 Sensor gefunden!");
    while (1) {}
  }
}

void loop() {
  Serial.println("-----");
  // Zunächst geben wir mal die Temperatur aus
  Serial.print("Temp: ");
  Serial.print(bmp.readTemperature());
  Serial.println(" °C");

  // dann den absoluten Druck
  Serial.print("Druck: ");
  Serial.print(bmp.readPressure());
  Serial.println(" Pa");

  // Zur Berechnung der aktuellen absoluten Höhe wird der 
  // Normaldruck von 1013.25 Millibar = 101325 Pascal verwendet
  Serial.print("Höhe: ");
  Serial.print(bmp.readAltitude());
  Serial.println(" m (ü. NN)");

  // Normaldruck auf Meereshöhe
  Serial.print("berechneter Druck bei NN: ");
  Serial.print(bmp.readSealevelPressure());
  Serial.println(" Pa");

  // Zur genaueren Berechnung der Höhe kann auch der Luftdruck 
  // auf Meereshöhe in Pascal angegeben werden.
  Serial.print("echte Höhe: ");
  Serial.print(bmp.readAltitude(101500));
  Serial.println(" m (ü. NN)");

  delay(1000);
}
