#include <Wire.h>
// Adresse des EEPROMs. 01010### ist die Basisadresse,
// ### werden durch die Eingänge E0..2 bestimmt.
#define EEPROM_DEVICE 0b01010000

// Hier wird ein einzelnes Byte in das EEPROM geschrieben
void eepromWriteByte(word address, byte data) {
  Wire.beginTransmission(EEPROM_DEVICE);
  Wire.write((int)(address >> 8)); // MSB
  Wire.write((int)(address & 0xFF)); // LSB
  Wire.write(data);
  Wire.endTransmission();
}

// Hier wird ein Block von Daten ins EEPROM geschrieben.
// die maimale Größe beträgt 30 Bytes, bedingt durch die Seitengröße des EEPROMs und
// der Puffergröße in der I2C Bibliothek
void eepromWritePage(word address, byte* data, byte length) {
  Wire.beginTransmission(EEPROM_DEVICE);
  Wire.write((int)(address >> 8)); // MSB
  Wire.write((int)(address & 0xFF)); // LSB
  for (byte c = 0; c < length; c++) {
    Wire.write(data[c]);
  }
  Wire.endTransmission();
}

// Lesen eines einzelnen Bytes aus dem EEPROM
byte eepromReadByte(word address) {
  byte data = 0xFF;
  Wire.beginTransmission(EEPROM_DEVICE);
  Wire.write((int)(address >> 8)); // MSB
  Wire.write((int)(address & 0xFF)); // LSB
  Wire.endTransmission();
  Wire.requestFrom(EEPROM_DEVICE, 1);
  if (Wire.available()) {
    data = Wire.read();
  }
  return data;
}

// Lesen eines Blocks von Bytes aus dem EEPROM,
// Einschränkungen wie beim Schreiben eines Blocks
void eepromReadBuffer(word address, byte *buffer, int length) {
  Wire.beginTransmission(EEPROM_DEVICE);
  Wire.write((int)(address >> 8)); // MSB
  Wire.write((int)(address & 0xFF)); // LSB
  Wire.endTransmission();
  Wire.requestFrom(EEPROM_DEVICE, length);
  for ( byte c = 0; c < length; c++ ) {
    if (Wire.available()) {
      buffer[c] = Wire.read();
    }
  }
}

void setup() {
  char message[] = "Dies ist ein Text der im EEPROM steht.";
  // I2C initialisieren
  Wire.begin();

  Serial.begin(9600);

  // Block ins EEPROM schreiben
  eepromWritePage(0, (byte *)message, sizeof(message));

  Serial.println("Text ins EEPROM übertragen.");
}

void loop() {
  Serial.println("Text aus EEPROM lesen.");
  int addr = 0;
  byte b = 0;
  do {
    // Zeichen lesen
    b = eepromReadByte(addr);
    if (b > 0) {
      // Zeichen ausgeben
      Serial.print((char)b);
      // nächstes Zeichen lesen
      addr++;
    }
  } while (b != 0);
  Serial.println();
  delay(1000);
}

