#include "logo.h"
#include <U8glib.h>

#define BACKLIGHT_PIN 3

// SPI Com: SCK = 13, MOSI = 11, SS = 10, A0 = 9
U8GLIB_DOGM128 dogm(10, 9);

// Kalibrierungsdaten für das Touchpanel
word min_x = 1024;
word max_x = 0;
word min_y = 1024;
word max_y = 0;

// aktuelle Position auf dem Touchpanel
word touchX, touchY;

void setup() {
  dogm.setContrast(48);
}

bool logoShowed = false;

#define font u8g_font_6x12

void showLogo() {
  analogWrite(BACKLIGHT_PIN, 255);
  dogm.firstPage();
  do {
    dogm.setFont(font);
    byte x = 0, y = 0;
    for (int i = 0; i < sizeof(LOGO); i++) {
      byte count = LOGO[i];
      for (byte p = 0; p < count; p++) {
        if ((i % 2) == 1) {
          dogm.drawPixel(x, y);
        }
        x++;
        if (x > 127) {
          x = 0;
          y++;
        }
      }
    }
  } while ( dogm.nextPage() );
  delay(10000);
}

void loop() {
  if (!logoShowed) {
    showLogo();
    logoShowed = true;
  } else {
    doWork();
  }
}

void doWork() {
  touchX = getTouchX();
  touchY = getTouchY();
  analogWrite(BACKLIGHT_PIN, 255);
  touchX = map(touchX, min_x, max_x, 0 , 127);
  touchY = map(touchY, min_y, max_y, 0 , 63);
  if (touchX < 0) touchX = -1;
  if (touchY < 0) {
    touchY = -1;
  } else {
    touchY = 64 - touchY;
  }
  dogm.firstPage();
  do {
    dogm.setFont(font);
    dogm.undoRotation();

    dogm.setColorIndex(1);
    if ((touchY > 1) && (touchY < 30)) {
      if ((touchX > 1) && (touchX < 42)) {
        dogm.drawRBox(1, 1, 40, 28, 6);
        dogm.setColorIndex(0);
      }
    }
    dogm.drawRFrame(0, 0, 42, 30, 7);
    dogm.drawStr(4, 13, "btn1");

    dogm.setColorIndex(1);
    if ((touchY > 1) && (touchY < 30)) {
      if ((touchX > 43) && (touchX < 85)) {
        dogm.drawRBox(44, 1, 40, 28, 6);
        dogm.setColorIndex(0);
      }
    }
    dogm.drawRFrame(43, 0, 42, 30, 7);
    dogm.drawStr(52, 13, "btn2");

    dogm.setColorIndex(1);
    if ((touchY > 1) && (touchY < 30)) {
      if ((touchX > 86) && (touchX < 128)) {
        dogm.drawRBox(87, 1, 40, 28, 6);
        dogm.setColorIndex(0);
      }
    }
    dogm.drawRFrame(86, 0, 42, 30, 7);
    dogm.drawStr(94, 13, "btn3");

    dogm.setColorIndex(1);
    dogm.setPrintPos(4, 54);
    dogm.print(F("Touch "));
    dogm.print(touchX, DEC);
    dogm.print(",");
    dogm.print(touchY, DEC);
  } while ( dogm.nextPage() );
}

