#include <SPI.h>

// Slave Select Pin
#define SS  10
#define BLINK  9

// Register im MAX6952
#define  NOOP               0x00
#define  INTENSITY10        0x01
#define  INTENSITY32        0x02
#define  SCAN_LIMIT         0x03
#define  CONFIGURATION      0x04
#define  USER_DEFINED_FONT  0x05
#define  DISPLAY_TEST       0x07
#define  DIGIT_0_P_0        0x20
#define  DIGIT_1_P_0        0x21
#define  DIGIT_2_P_0        0x22
#define  DIGIT_3_P_0        0x23
#define  DIGIT_0_P_1        0x40
#define  DIGIT_1_P_1        0x41
#define  DIGIT_2_P_1        0x42
#define  DIGIT_3_P_1        0x43
#define  DIGIT_0            0x60
#define  DIGIT_1            0x61
#define  DIGIT_2            0x62
#define  DIGIT_3            0x63

// einige praktische Registerinhalte
#define SHUTDOWN_MODE        0b00000001
#define BLINK_RATE           0b00000100
#define GLOBAL_BLINK_ENABLE  0b00001000
#define GLOBAL_BLINK_TIMING  0b00010000
#define GLOBAL_CLEAR_DIGIT   0b00100000
#define SCAN_LIMIT_4_DIGITS  0b00000001
#define SCAN_LIMIT_2_DIGITS  0b00000000

void sendData(byte adr, byte data) {
  digitalWrite(SS, LOW);
  SPI.transfer(adr);
  SPI.transfer(data);
  digitalWrite(SS, HIGH);
  delay(1);
}

void setIntensity(byte intensity) {
  // Intensität im Bereich von 0..15
  intensity = intensity & 0x0f;
  intensity = intensity + (intensity << 4);

  sendData(INTENSITY10, intensity);
  sendData(INTENSITY32, intensity);
}


void setup() {
  SPI.begin();

  // Slave Select und Blink Pin initialisieren
  pinMode(SS, OUTPUT);
  pinMode(BLINK, OUTPUT);

  // Konfigurationen senden
  sendData(CONFIGURATION, SHUTDOWN_MODE + GLOBAL_BLINK_ENABLE);
  // Scan Limit 1 = 4 Digits,  Scan Limit 0 = 2 Digits
  sendData(SCAN_LIMIT, SCAN_LIMIT_4_DIGITS);
  setIntensity(15);

  // Displaytest
  sendData(DISPLAY_TEST, true);
  delay(250);
  sendData(DISPLAY_TEST, false);
  digitalWrite(BLINK, false);
}

byte value = 0;
void loop() {
  // jetzt ein paar Werte anzeigen
  sendData(DIGIT_0_P_0, value);
  sendData(DIGIT_1_P_0, value+1);
  sendData(DIGIT_2_P_0, value+2);
  sendData(DIGIT_3_P_0, value+3);
  delay(100);
  value += 1;
}
