#include <SPI.h>

// Definition der verschiedenen SPI Pins
#define SS 10
#define MOSI 11
#define MISO 12
#define CLOCK 13
#define SPI_CLOCK 250000
#define ANALOG_IN 0

#define APOSTROPHE  5
#define COLON       4
#define DECIMAL4    3
#define DECIMAL3    2
#define DECIMAL2    1
#define DECIMAL1    0

#define SEGMENT1  0
#define SEGMENT2  1
#define SEGMENT3  2
#define SEGMENT4  3
#define SEGMENT5  4
#define SEGMENT6  5
#define SEGMENT7  6

#define DIGIT1  0x7B
#define DIGIT2  0x7C
#define DIGIT3  0x7D
#define DIGIT4  0x7E


// Einstellungen bleiben default,
// nur die Geschwindigkeit muss gedrosselt werden
SPISettings mySpiSettings(SPI_CLOCK,  MSBFIRST, SPI_MODE0);

void setup() {
  pinMode(SS, OUTPUT);
  digitalWrite(SS, HIGH);

  // Start der SPI Hardware
  SPI.beginTransaction(mySpiSettings);
  // Baustein selektieren
  digitalWrite(SS, LOW);
  // ausführen eines Resets
  SPI.transfer('v');
  // Baustein deselektieren
  digitalWrite(SS, HIGH);
}

void loop() {
  // Lesen des Wertes vom analogen Eingang
  int value = analogRead(ANALOG_IN);

  // Baustein selektieren
  digitalWrite(SS, LOW);

  // 1. Ziffer senden (mit führenden Nullen)
  SPI.transfer(value / 1000); //Send the left most digit
  // 1. Ziffer vom enchten Wert entfernen
  value %= 1000;
  // dsa gleiche für die 2. Ziffer
  SPI.transfer(value / 100);
  value %= 100;
  // und die 3. ziffer
  SPI.transfer(value / 10);
  // und zuletzt die 4. Ziffer
  value %= 10;
  SPI.transfer(value);

  // Baustein deselektieren
  digitalWrite(SS, HIGH);

  setSpecialSegments((1 << APOSTROPHE) | (1 << COLON) | (1 << DECIMAL4));
  delay(1000);

  setSegments(DIGIT1, (1 << SEGMENT1) | (1 << SEGMENT4) | (1 << SEGMENT7) );
  delay(1000);

  sendString("1234");
  // 1 Sekunde warten
  delay(1000);
}

void setBrightness(byte brightness) {
  digitalWrite(SS, LOW);
  // Kommando Helligkeit
  SPI.transfer(0x7A);
  delay(1);
  SPI.transfer(brightness);
  digitalWrite(SS, HIGH);
}

void setSpecialSegments(byte special) {
  digitalWrite(SS, LOW);
  // Kommando Spezialsegmente
  SPI.transfer(0x77);
  delay(1);
  SPI.transfer(special);
  digitalWrite(SS, HIGH);
}

void setSegments(byte digit, byte segments) {
  digitalWrite(SS, LOW);
  SPI.transfer(digit);
  delay(1);
  SPI.transfer(segments);
  digitalWrite(SS, HIGH);
}

void sendString(char *toSend)
{
  // Baustein selektieren
  digitalWrite(SS, LOW);
  // Resetkommando
  SPI.transfer('v'); 
  // Baustein deselektieren
  digitalWrite(SS, HIGH);

  // Baustein selektieren
  digitalWrite(SS, LOW);
  for (byte x = 0 ; x < 4 ; x++)
  {
    // kleine Verzögerung
    delay(1); 
    // Zeichen versenden
    SPI.transfer(toSend[x]);
  }
  // Baustein deselektieren
  digitalWrite(SS, HIGH);
}
