#define START_MESSAGE PSTR("PMSPST,Data Collecting v1")
#define VCC_MESSAGE PSTR("PMSPVC,%i")
#define ADC_MESSAGE PSTR("PMSPAC,%i,%i")
#define MAX_NMEA_BUFFER 80

#define AD_CHANNEL_1 0
#define AD_CHANNEL_2 1

void setup() {
  Serial.begin(115000);
  while (!Serial) {
    // warten auf den Host (Leonardo)
  }
  writeStartMessage();
}

word vcc;
word adValue1;
word adValue2;
char linedata[MAX_NMEA_BUFFER];

void loop() {
  long now = millis();
  // Spannungsversorgung lesen
  vcc = readVcc();
  writeVCC();

  // A/D Kanal 1 und 2 lesen
  adValue1 = analogRead(AD_CHANNEL_1);
  writeADC(1, adValue1);

  adValue2 = analogRead(AD_CHANNEL_2);
  writeADC(2, adValue2);

  delay(10000);
}

/**
 * Auslesen der aktuellen Betriebsspannung des Boards
 **/
word readVcc() {
  long result;
  // 1.1V Referenspannug gegen AVcc lesen
  ADMUX = _BV(REFS0) | _BV(MUX3) | _BV(MUX2) | _BV(MUX1);
  delay(2); // Warten bis Vref stabil
  ADCSRA |= _BV(ADSC); // lesen
  while (bit_is_set(ADCSRA, ADSC));
  result = ADCL;
  result |= ADCH << 8;
  result = 1126400L / result; // Umrechnung von AVcc in mV
  return result;
}

/**
 * Start Meldung ausgeben.
 **/
inline void writeStartMessage() {
  strcpy_P(linedata, START_MESSAGE);
  writeNMEAData(linedata);
}

/**
 * Vcc Meldung erzeugen und ausgeben.
 **/
inline void writeVCC() {
  sprintf_P(linedata, VCC_MESSAGE, vcc);
  writeNMEAData(linedata);
}

/**
 * A/D Meldung erzeugen und ausgeben.
 **/
inline void writeADC(byte channel, word value) {
  sprintf_P(linedata, ADC_MESSAGE, channel, value);
  writeNMEAData(linedata);
}

/**
 * NMEA Datagram erzeugen und ausgeben.
 **/
void writeNMEAData(char* data) {
  byte crc = 0;
  for (byte i = 0; i < strlen(data); i++) {
    crc ^= data[i];
  }
  Serial.write('$');
  Serial.print(data);
  Serial.write('*');
  if (crc < 16) {
    Serial.write('0');
  }
  Serial.println(crc, HEX);
}

