#include <AltSoftSerial.h>

#define START_MESSAGE PSTR("PMSPST,Data Collecting v2")
#define VCC_MESSAGE PSTR("PMSPVC,%i")
#define ADC_MESSAGE PSTR("PMSPAC,%i,%i")
#define MAX_NMEA_BUFFER 80

#define AD_CHANNEL_1 0
#define AD_CHANNEL_2 1

#define NMEABAUD 9600

// Port für NMEA Eingang
AltSoftSerial nmSerial;

void setup() {
  Serial.begin(115000);
  while (!Serial) {
    // warten auf den Host (Leonardo)
    writeStartMessage();

    // 2. Schnittstelle für NMEA0183 Eingang
    nmSerial.begin(NMEABAUD);
  }

  word vcc;
  word adValue1;
  word adValue2;
  char linedata[MAX_NMEA_BUFFER];
  byte nmBuffer[MAX_NMEA_BUFFER];
  byte nmIndex = 0;
  long lastTime = 0;

  void loop() {
    if ((lastTime + 1000 ) < millis()) {
      // Spannungsversorgung lesen
      vcc = readVcc();
      writeVCC();

      // A/D Kanal 1 und 2 lesen
      adValue1 = analogRead(AD_CHANNEL_1);
      writeADC(1, adValue1);

      adValue2 = analogRead(AD_CHANNEL_2);
      writeADC(2, adValue2);
      lastTime = millis();
    }
    // Daten vom NMEA Port lesen
    testNMEA();
  }

  boolean ending = false;
  /**
   * hier werden nun die Daten der 2. seriellen Schnittstelle
   * in einem Puffer gespeichert und wenn entweder ein CRLF
   * kommt oder der Puffer voll ist direkt auf die 1. serielle
   * Schnittstelle ausgegeben.
   */
  void testNMEA() {
    ending = false;
    while ((nmSerial.available()  > 0) && !ending) {
      int incomingByte = nmSerial.read();
      if (incomingByte >= 0) {
        byte in = lowByte(incomingByte);
        if (in == 0x0A) {
          ending = true;
        }
        else {
          if (in != 0x0D) {
            nmBuffer[nmIndex] = (byte) in;
            nmIndex++;
          }
        }
        if (ending || (nmIndex >= MAX_NMEA_BUFFER)) {
          if (nmIndex > 0) {
            Serial.write(nmBuffer, nmIndex);
            Serial.println();
            nmIndex = 0;
          }
        }
      }
    }
  }

  /**
   * Auslesen der aktuellen Betriebsspannung des Boards
   **/
  word readVcc() {
    long result;
    // 1.1V Referenspannug gegen AVcc lesen
    ADMUX = _BV(REFS0) | _BV(MUX3) | _BV(MUX2) | _BV(MUX1);
    delay(2); // Warten bis Vref stabil
    ADCSRA |= _BV(ADSC); // lesen
    while (bit_is_set(ADCSRA, ADSC));
    result = ADCL;
    result |= ADCH << 8;
    result = 1126400L / result; // Umrechnung von AVcc in mV
    return result;
  }

  /**
   * Start Meldung ausgeben.
   **/
  inline void writeStartMessage() {
    strcpy_P(linedata, START_MESSAGE);
    writeNMEAData(linedata);
  }

  /**
   * Vcc Meldung erzeugen und ausgeben.
   **/
  inline void writeVCC() {
    sprintf_P(linedata, VCC_MESSAGE, vcc);
    writeNMEAData(linedata);
  }

  /**
   * A/D Meldung erzeugen und ausgeben.
   **/
  inline void writeADC(byte channel, word value) {
    sprintf_P(linedata, ADC_MESSAGE, channel, value);
    writeNMEAData(linedata);
  }

  /**
   * NMEA Datagram erzeugen und ausgeben.
   **/
  void writeNMEAData(char * data) {
    byte crc = 0;
    for (byte i = 0; i < strlen(data); i++) {
      crc ^= data[i];
    }
    Serial.write('$');
    Serial.print(data);
    Serial.write('*');
    if (crc < 16) {
      Serial.write('0');
    }
    Serial.println(crc, HEX);
  }

