//#include "FastSPI_LED2.h"
#include "Adafruit_NeoPixel.h"

// Anzahl der LEDs
#define NUM_LEDS 7

// Datenpin der LEDs
#define DATA_PIN 11

// Initialisieren der Jewel Struktur
Adafruit_NeoPixel pixels = Adafruit_NeoPixel(NUM_LEDS, DATA_PIN, NEO_GRB + NEO_KHZ800);

void setup() {
  // Initialisieren der seriellen Verbindung zum Host
  Serial.begin(9600);
  // NeoPixel Bibliothek starten
  pixels.begin();
  // Willkommensmeldung ausgeben
  Serial.println("SkypeStatus V0.1");
}

long time = 0;
boolean blink = false;
boolean connect = false;
// 1. Farbe nach dem Start soll rot sein
byte red = 64, green = 0, blue = 0;

void loop() {
  if (Serial.available() > 0) {
    processPCData();
  } else if (!connect) {
    fadeAllColors();
  } else {
    if (blink) {
      Serial.print("b");
      if ((time % 2) == 0) {
        Serial.print("on");
        pixels.setBrightness(255);
      } else {
        Serial.print("off");
        pixels.setBrightness(1);
      }
    }
    pixels.show();
    Serial.print("after show ");
    Serial.println(time);

    time++;
    // wenn Verbindung zum Host besteht, muss jede Minute ein Update kommen
    if (time > 60) {
      time = 0;
      connect = false;
    }
    delay(1000);
  }
}

// verarbeiten der Daten vom Host, Format "#index,r,g,b[,'b']"
// index: 0 für alle LEDs, 1..MAX_LEDS für eine einzelne LED
// r: integer Wert der Farbe Rot 0..255
// g: integer Wert der Farbe Grün 0..255
// b: integer Wert der Farbe Blau 0..255
// b: optionales Zeichen 'b' für blinkend
void  processPCData() {
  // erstes Zeichen muss ein '#' sein
  if (Serial.read() == '#') {
    Serial.print('H');
    // Jetzt zunächst den Index und die 3 Farben lesen
    // Danach das b oder das Ende-Kennzeichen
    int index = Serial.parseInt();
    Serial.print('I');
    int red = Serial.parseInt();
    Serial.print('R');
    int green = Serial.parseInt();
    Serial.print('G');
    int blue = Serial.parseInt();
    Serial.print('B');
    byte myChar = Serial.read();
    Serial.print('C');
    Serial.print(myChar);
    if (myChar == 'b') {
      blink = true;
      myChar = Serial.read();
      Serial.print('D');
    } else {
      blink = false;
    }
    if (myChar == '*') {
      index = constrain(index, 0, NUM_LEDS);
      red = constrain(red, 0, 255);
      green = constrain(green, 0, 255);
      blue = constrain(blue, 0, 255);

      Serial.print(index);
      Serial.print(':');
      Serial.print(red, HEX);
      Serial.print('.');
      Serial.print(green, HEX);
      Serial.print('.');
      Serial.println(blue, HEX);
      clear();
      pixels.setBrightness(255);
      showColor(index, pixels.Color(red, green, blue));
      time = 0;
      connect = true;
    } else {
      clear();
    }
  }
}

// Alle Farben durchgehen, aber bitte nicht zu hell...
void fadeAllColors() {
  if (red == 64) {
    red = 63;
    green = 1;
    blue = 0;
  } else if (red > 0 && green < 64 && blue == 0) {
    red--;
    green++;
  } else if (green == 64) {
    green = 63;
    blue = 1;
    red = 0;
  } else if (green > 0 && blue < 64 && red == 0) {
    green--;
    blue++;
  } else if (blue == 64) {
    blue = 63;
    red = 1;
    green = 0;
  } else if (blue > 0 && red < 64 && green == 0) {
    blue--;
    red++;
  }
  blink = false;
  showColor(0, pixels.Color(red, green, blue));
  delay(100);
}

// eine LED auf Farbe setzen
void setLED(byte index, uint32_t color) {
  index = index % NUM_LEDS;
  pixels.setPixelColor(index, color);
}

// Farbe für die gewünschten LED ssetzen
void showColor(int index, uint32_t color) {
  if (index == 0) {
    // set the color for all LEDs
    for (int i = 0; i < NUM_LEDS; i++) {
      setLED(i, color);
    }
  } else {
    // just set one led color
    setLED(index - 1, color);
  }
  // now shot the color
  pixels.show();
}

// alle Farben löschen
void clear() {
  for (int i = 0; i < NUM_LEDS; i++) {
    setLED(i, pixels.Color(0, 0, 0));
  }
  pixels.show();
}
