#!/usr/bin/python
import smbus
import math

#liest ein einzelnes Byte
def read_byte(address, adr):
    return bus.read_byte_data(address, adr)

#liest ein einfaches word in MSB
def read_word(address, adr):
    high = bus.read_byte_data(address, adr)
    low = bus.read_byte_data(address, adr+1)
    value = (high << 8) + low
    return value

#liest ein word mit Vorzeichen
def read_signed_word(address, adr):
    val = read_word(address, adr)
    if (val >= 0x8000):
        return -((65535 - val) + 1)
    else:
        return val

#ergibt die aktuelle Drehung in Grad
def get_rotation(x,y,z):
    radians = math.atan2(y, math.sqrt((x**2)+(z**2)))
    return math.degrees(radians)
	
#I2C Bus 0 initialisieren 
bus = smbus.SMBus(0)
#Adresse des MPU6050
address = 0x68

#zunächst muss der MPU6050 gestartet werden
bus.write_byte_data(address, 0x6b, 0)

gyro_x = read_signed_word(address, 0x43)
gyro_y = read_signed_word(address, 0x45)
gyro_z = read_signed_word(address, 0x47)

print ("gyro: X: %5d, Y: %5d, Z: %5d" % (gyro_x, gyro_y, gyro_z))

acc_x = read_signed_word(address, 0x3b)
acc_y = read_signed_word(address, 0x3d)
acc_z = read_signed_word(address, 0x3f)

acc_x_s = acc_x / 16384.0
acc_y_s = acc_y / 16384.0
acc_z_s = acc_z / 16384.0

print ("acc : X: %5d/%2.3f, Y: %5d/%2.3f, Z: %5d/%2.3f" % (acc_x, acc_x_s, acc_y, acc_y_s, acc_z, acc_z_s))

rot_x = get_rotation(acc_x_s, acc_y_s, acc_z_s)
rot_y = get_rotation(acc_y_s, acc_x_s, acc_z_s)
print ("rot : X: %3.3f°, Y: %3.3f°" % (rot_x, rot_y))
