import time
from datetime import datetime
from neopixel import *

# LED strip configuration:
LED_COUNT      = 24      # Number of LED pixels.
LED_PIN        = 18      # GPIO pin connected to the pixels (must support PWM!).
LED_FREQ_HZ    = 800000  # LED signal frequency in hertz (usually 800khz)
LED_DMA        = 5       # DMA channel to use for generating signal (try 5)
LED_BRIGHTNESS = 255     # Set to 0 for darkest and 255 for brightest
LED_INVERT     = False   # True to invert the signal (when using NPN transistor level shift)
COLOR_SEC = Color(0,0,255)
COLOR_MIN =  Color(0,255,0)
COLOR_HOUR =  Color(255,0,0)

# Setzen einer bestimmten LED Index auf Farbe
def setLED(index, color) :
	# Der index muss umgekehrt werden, da der Ring mit den 
	# LED's zur Wand zeigen soll und somit natürlich links herum läuft.
	index = index % LED_COUNT
	index = (LED_COUNT) - index
	index = index % LED_COUNT
	strip.setPixelColor(index, color)

# Anzeigen der aktuellen Uhrzeit
def showTime():
	# Markierungen setzen
	for i in range(LED_COUNT):
		# zunächst soll jede LED etwas leuchten
		strip.setPixelColor(i, Color(2,2,2))
		# jede 2. LED etwas heller, damit werden die Stunden markiert
		if ((i % 2) == 0) :
			strip.setPixelColor(i, Color(16,16,16))
		# jede 6. noch heller, das sind die 3, 6, 9 und 12
		if ((i % 6) == 0) :
			strip.setPixelColor(i, Color(64,64,64))
			
	# jetzt wird die aktuelle Uhrzeit geholt
	now = datetime.now()
	print ("Time now:" + str(now))
	# Berechnung des Index der LED für die aktuelle Stunde
	h = now.hour;
	if h > 12:
		h = h - 12
	h = (h * LED_COUNT / 12)
	
	# Berechnung des Index der LED für die aktuelle Minute
	mm = now.minute
	mm = mm * LED_COUNT / 60

	# Berechnung des Index der LED für die aktuelle Sekunde
	sec = now.second
	sec = sec * LED_COUNT / 60
	
	# Setzen der entsprechenden Farben
	setLED(sec, COLOR_SEC)
	setLED(mm, COLOR_MIN)
	setLED(h, COLOR_HOUR)
	
	print("Index: s={0},m={1},h={2}".format(sec, mm,h))
	
	# und Anzeige aktualisieren
	strip.show()

# Main program logic follows:
if __name__ == '__main__':
	# Erzeuge ein neues NeoPixel Objekt mit den entsprechenden Einstellungen für den 24'er Ring
	strip = Adafruit_NeoPixel(LED_COUNT, LED_PIN, LED_FREQ_HZ, LED_DMA, LED_INVERT, LED_BRIGHTNESS)
	# Initialisierung der Bibliothek. Muss einmal aufgerufen werden bevor die Bibliothek verwendet werden kann.
	strip.begin()

	print 'Press Ctrl-C to quit.'
	while True:
		strip.setBrightness(255)
		showTime()
		time.sleep(0.2)
